
import java.util.ArrayList;
import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;


public class SwtMain {
	private List<Control> sizeWidetList;
	private List<Control> bitrateWidetList;
	private List<Control> sterioWidetList; 
	private List<Control> geotagWidetList;
	private Shell shell;
	private FileType fileType = FileType.PLAIN;
	
	public static void main(String[] args) {
		new SwtMain().startApp();
	}

	public void startApp() {
		Display display = new Display();
		shell = new Shell(display);
		init();
		shell.open();
		while (!shell.isDisposed()) {
			if (!display.readAndDispatch())
				display.sleep();
		}
		display.dispose();
	}
	
	private void init() {
		sizeWidetList = new ArrayList<Control>();   
		bitrateWidetList = new ArrayList<Control>();
		sterioWidetList = new ArrayList<Control>(); 
		geotagWidetList = new ArrayList<Control>(); 
		
		shell.setSize(250, 300);
		GridLayout layout = new GridLayout(2, false);
		shell.setLayout(layout);
		shell.setText("File meta data");
		
		new Label(shell, SWT.NONE).setText("File name:");
		new Label(shell, SWT.NONE).setText("/home/boris/my-file");
		new Label(shell, SWT.NONE).setText("File type:");
		final Combo combo = new Combo(shell, SWT.DROP_DOWN | SWT.READ_ONLY);
		combo.setLayoutData(new GridData(SWT.FILL, 0, true, false));
		for (FileType fileType : FileType.values()) {
			combo.add(fileType.getText());
		}
		combo.select(0);
		combo.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent arg0) {
				fileType = FileType.values()[combo.getSelectionIndex()];
				refreshCustomFields();
			}
		});

		Label label = new Label(shell, SWT.NONE);
		label.setText("Width:");
		sizeWidetList.add(label);
		Text text = new Text(shell, SWT.BORDER);
		sizeWidetList.add(text);
		
		label = new Label(shell, SWT.NONE);
		label.setText("Height:");
		sizeWidetList.add(label);
		text = new Text(shell, SWT.BORDER);
		sizeWidetList.add(text);

		label = new Label(shell, SWT.NONE);
		label.setText("Bit rate:");
		bitrateWidetList.add(label);
		Composite composite = horizontalComposite(shell);
		new Text(composite, SWT.BORDER);
		new Label(composite, SWT.NONE).setText("kbit/s");
		bitrateWidetList.add(composite);
		
		label = new Label(shell, SWT.NONE);
		label.setText("Sterio:");
		sterioWidetList.add(label);
		Button button = new Button(shell, SWT.CHECK);
		sterioWidetList.add(button);
		
		label = new Label(shell, SWT.NONE);
		label.setText("Geo Tag:");
		geotagWidetList.add(label);
		composite = horizontalComposite(shell);
		new Text(composite, SWT.BORDER);
		new Label(composite, SWT.NONE).setText("Latitude");
		geotagWidetList.add(composite);

		geotagWidetList.add(new Label(shell, SWT.NONE));
		composite = horizontalComposite(shell);
		new Text(composite, SWT.BORDER);
		new Label(composite, SWT.NONE).setText("Longitude");
		geotagWidetList.add(composite);
		shell.pack();
		refreshCustomFields();
	}
	
	private Composite horizontalComposite(Shell shell) {
		Composite composite = new Composite(shell, SWT.NONE);
		GridLayout gridLayout = new GridLayout(2, false);
		gridLayout.horizontalSpacing = gridLayout.marginWidth;
		gridLayout.marginWidth = 0;
		gridLayout.marginHeight = 0;
		composite.setLayout(gridLayout);
		composite.setLayoutData(new GridData(SWT.LEFT, SWT.NONE, true, false));
		return composite;
	}
	
	protected void refreshCustomFields() {
		hideShow(sizeWidetList, fileType.isSize());
		hideShow(bitrateWidetList, fileType.isBitrate());
		hideShow(sterioWidetList, fileType.isSterio());
		hideShow(geotagWidetList, fileType.isGeotag());
		shell.layout();
	}
	
	private void hideShow(List<Control> list, boolean show) {
		for (Control control : list) {
			control.setVisible(show);
			if (control.getLayoutData() == null) {
				control.setLayoutData(new GridData());
			}
			((GridData)control.getLayoutData()).exclude = !show;
		}
	}
}
