package org.xtext.example.mydsl.serializer;

import com.google.inject.Inject;
import com.google.inject.Provider;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.xtext.serializer.acceptor.ISemanticSequenceAcceptor;
import org.eclipse.xtext.serializer.diagnostic.ISemanticSequencerDiagnosticProvider;
import org.eclipse.xtext.serializer.diagnostic.ISerializationDiagnostic.Acceptor;
import org.eclipse.xtext.serializer.sequencer.AbstractSemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.GenericSequencer;
import org.eclipse.xtext.serializer.sequencer.ISemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService;
import org.xtext.example.mydsl.pEnum.Model;
import org.xtext.example.mydsl.pEnum.PEnum;
import org.xtext.example.mydsl.pEnum.PEnumElement;
import org.xtext.example.mydsl.pEnum.PEnumElementParamaterValue;
import org.xtext.example.mydsl.pEnum.PEnumPackage;
import org.xtext.example.mydsl.services.PEnumGrammarAccess;

@SuppressWarnings("restriction")
public class AbstractPEnumSemanticSequencer extends AbstractSemanticSequencer {

	@Inject
	protected PEnumGrammarAccess grammarAccess;
	
	@Inject
	protected ISemanticSequencerDiagnosticProvider diagnosticProvider;
	
	@Inject
	protected ITransientValueService transientValues;
	
	@Inject
	@GenericSequencer
	protected Provider<ISemanticSequencer> genericSequencerProvider;
	
	protected ISemanticSequencer genericSequencer;
	
	
	@Override
	public void init(ISemanticSequencer sequencer, ISemanticSequenceAcceptor sequenceAcceptor, Acceptor errorAcceptor) {
		super.init(sequencer, sequenceAcceptor, errorAcceptor);
		this.genericSequencer = genericSequencerProvider.get();
		this.genericSequencer.init(sequencer, sequenceAcceptor, errorAcceptor);
	}
	
	public void createSequence(EObject context, EObject semanticObject) {
		if(semanticObject.eClass().getEPackage() == PEnumPackage.eINSTANCE) switch(semanticObject.eClass().getClassifierID()) {
			case PEnumPackage.MODEL:
				if(context == grammarAccess.getModelRule()) {
					sequence_Model(context, (Model) semanticObject); 
					return; 
				}
				else break;
			case PEnumPackage.PENUM:
				if(context == grammarAccess.getPEnumRule()) {
					sequence_PEnum(context, (PEnum) semanticObject); 
					return; 
				}
				else break;
			case PEnumPackage.PENUM_ELEMENT:
				if(context == grammarAccess.getPEnumElementRule()) {
					sequence_PEnumElement(context, (PEnumElement) semanticObject); 
					return; 
				}
				else break;
			case PEnumPackage.PENUM_ELEMENT_PARAMATER_VALUE:
				if(context == grammarAccess.getPEnumElementParamaterValueRule()) {
					sequence_PEnumElementParamaterValue(context, (PEnumElementParamaterValue) semanticObject); 
					return; 
				}
				else break;
			}
		if (errorAcceptor != null) errorAcceptor.accept(diagnosticProvider.createInvalidContextOrTypeDiagnostic(semanticObject, context));
	}
	
	/**
	 * Constraint:
	 *     penums+=PEnum*
	 */
	protected void sequence_Model(EObject context, Model semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (value?='+'?)
	 */
	protected void sequence_PEnumElementParamaterValue(EObject context, PEnumElementParamaterValue semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID alternateText=STRING? parameterValueList+=PEnumElementParamaterValue*)
	 */
	protected void sequence_PEnumElement(EObject context, PEnumElement semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID parameterNameList+=ID* elements+=PEnumElement*)
	 */
	protected void sequence_PEnum(EObject context, PEnum semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
}
